************
Usersettings
************

.. _usage_profile:

Profile
=======
.. image:: ../screenshots/profile.png
   :width: 800
   :alt: Profile dialog of Ringo 

.. _usage_changepassword:

Change Password
===============
